==> happy-dom-0.2.12.tgz: package/src/VMContext.ts <==
import VM from 'vm';
import AsyncWindow from './AsyncWindow';

/**
 * This class is used for rendering a script server side.
 */
export default class VMContext {
	private context: VM.Context = this.createContext();

	/**
	 * Returns route HTML.
	 *
	 * @param {object} options Options.
	 * @param {string} options.html HTML.
	 * @param {VM.Script} [options.script] Script.
	 * @param {string} [options.url] Page URL.
	 * @param {boolean} [options.openShadowRoots=false] Set to "true" to open up shadow roots.
	 * @return {Promise<string>} HTML.
	 */
	public async render(options: {
		html: string;
		script: VM.Script;
		url?: string;
		openShadowRoots: boolean;
	}): Promise<string> {
		return new Promise((resolve, reject) => {
			const window = this.context.window;
			const document = this.context.document;

			window
				.whenAsyncComplete()
				.then(() => resolve(document.documentElement.outerHTML))
				.catch(reject);

			if (options.url) {
				window.location.href = options.url;
			}

			window.shadowRootRenderOptions.openShadowRoots = options.openShadowRoots === true;

			options.script.runInContext(this.context);

			document.write(options.html);
		});
	}

	/**
	 * Disposes the render.
	 */
	public dispose(): void {
		this.context.window.dispose();
		this.context.dispose();
	}

	/**
	 * Creates a context.
	 *
	 * @return {VM.Context} Context.
	 */
	private createContext(): VM.Context {
		const window = new AsyncWindow();
		const sandbox = Object.assign({}, window, { window, global });
		return VM.createContext(sandbox);
	}
}

==> happy-dom-0.2.13.tgz: package/src/VMContext.ts <==
import VM from 'vm';
import AsyncWindow from './AsyncWindow';

/**
 * This class is used for rendering a script server side.
 */
export default class VMContext {
	private context: VM.Context = this.createContext();

	/**
	 * Returns route HTML.
	 *
	 * @param {object} options Options.
	 * @param {string} options.html HTML.
	 * @param {VM.Script} [options.script] Script.
	 * @param {string} [options.url] Page URL.
	 * @param {boolean} [options.openShadowRoots=false] Set to "true" to open up shadow roots.
	 * @return {Promise<string>} HTML.
	 */
	public async render(options: {
		html: string;
		script: VM.Script;
		url?: string;
		openShadowRoots: boolean;
	}): Promise<string> {
		return new Promise((resolve, reject) => {
			const window = this.context.window;
			const document = this.context.document;

			window
				.whenAsyncComplete()
				.then(() => resolve(document.documentElement.outerHTML))
				.catch(reject);

			if (options.url) {
				window.location.href = options.url;
			}

			window.shadowRootRenderOptions.openShadowRoots = options.openShadowRoots === true;

			options.script.runInContext(this.context);

			document.write(options.html);
		});
	}

	/**
	 * Disposes the render.
	 */
	public dispose(): void {
		this.context.window.dispose();
		this.context.dispose();
	}

	/**
	 * Creates a context.
	 *
	 * @return {VM.Context} Context.
	 */
	private createContext(): VM.Context {
		const sandbox = new AsyncWindow();
		sandbox['window'] = window;
		sandbox['global'] = global;
		return VM.createContext(sandbox);
	}
}
